// VolKool2
// OEN170327

#include <Wire.h>
#include "Adafruit_TCS34725.h"

// Resistance de 220 ohm sur les 3 LED.
// Si la verte brille trop, double la valeur de sa résistance
#define brRouge 3
#define brVerte 5
#define brBleue 6

#define anodeComm true  // Indiquer false si cathode comm.

// Table des gamma
byte tabGamma[256];

Adafruit_TCS34725 monTCS = 
  Adafruit_TCS34725(TCS34725_INTEGRATIONTIME_50MS, TCS34725_GAIN_4X);

void setup() {
  Serial.begin(9600);
  Serial.println("Le voleur de couleur !");

  if (monTCS.begin()) {
    Serial.println("Capteur actif.");
  } else {
    Serial.println("Pas de TCS34725... verifier les branchements.");
    while (1);
  }
  
  pinMode(brRouge, OUTPUT);
  pinMode(brVerte, OUTPUT);
  pinMode(brBleue, OUTPUT);
  
  // Merci PhilB pour la gamma table.
  // Elle reequilibre la luminosite selon l'oeil humain.
  for (int i=0; i<256; i++) {
    float fGam = i;
    fGam /= 255;
    fGam = pow(fGam, 2.5);
    fGam *= 255;
      
    if (anodeComm) {
      tabGamma[i] = 255 - fGam;
    } else {
      tabGamma[i] = fGam;      
    }
    Serial.print(tabGamma[i]);
    Serial.print(" ");
  }
    Serial.println();
}

void loop() {
  uint16_t clear, iRO, iVE, iBL;

  monTCS.setInterrupt(false);
  delay(60);                    // Patiente 50ms pour la lecture
  monTCS.getRawData(&iRO, &iVE, &iBL, &clear);
  monTCS.setInterrupt(true);
  
  Serial.println();
  Serial.print("C:\t"); Serial.print(clear);
  Serial.print("\tR:\t"); Serial.print(iRO);
  Serial.print("\tG:\t"); Serial.print(iVE);
  Serial.print("\tB:\t"); Serial.println(iBL);

  // Calcul des valeurs hexa pour le web
  uint32_t sum = clear;
  float r, g, b;
  r = iRO; r /= sum;
  g = iVE; g /= sum;
  b = iBL; b /= sum;
  r *= 256; g *= 256; b *= 256;

  Serial.print(" Couleurs web \t\t");
  Serial.print((int)r, HEX); 
  Serial.print((int)g, HEX); 
  Serial.print((int)b, HEX);
  Serial.println();

  Serial.print(" Couleurs de base \t");
  Serial.print((int)r ); Serial.print(" "); 
  Serial.print((int)g ); Serial.print(" ");  
  Serial.println((int)b );

  analogWrite(brRouge, tabGamma[(int)r]);
  analogWrite(brVerte, tabGamma[(int)g]);
  analogWrite(brBleue, tabGamma[(int)b]);
  delay(1000);
}

