// Version revue pour Arduikidz au niveau de TimeSpan 
// OE 20170402
// Pour circuit RTC DS1307 dialoguant via I2C et donc Wire
#include <Wire.h>
#include "RTClib.h"

RTC_DS1307 rtc;

char daysOfTheWeek[7][12] = {"Dimanche", "Lundi", "Mardi", 
                             "Mercredi", "Jeudi", "Vendredi", "Samedi"};

void setup () {
  Serial.begin(9600);        // Vitesse standard au lieu de 57600
  if (! rtc.begin()) {
    Serial.println("Pas de circuit horloge RTC");
    while (1);
  }

  if (! rtc.isrunning()) {
    Serial.println("RTC introuvable !");
    // Aligne le circuit sur la date et heure de l'ordinateur lors de la compilation 
    rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));
    // Pour changer la valeur librement :
    // rtc.adjust(DateTime(aaaa, mm, jj, hh, mm, ss));
  }
}

void loop () {
    DateTime now = rtc.now();
    
    Serial.print("Nous sommes le ");
    Serial.print(now.year(), DEC);
    Serial.print('/');
    Serial.print(now.month(), DEC);
    Serial.print('/');
    Serial.print(now.day(), DEC);
    Serial.print(" (");
    Serial.print(daysOfTheWeek[now.dayOfTheWeek()]);
    Serial.print(") ");
    Serial.print(now.hour(), DEC);
    Serial.print(':');
    Serial.print(now.minute(), DEC);
    Serial.print(':');
    Serial.print(now.second(), DEC);
    Serial.println();
    
    Serial.print("Naissance de Unix le 1/1/1970, il y a ");
    Serial.print(now.unixtime());
    Serial.print(" sec. ou ");
    Serial.print(now.unixtime() / 86400L);
    Serial.println(" jours.");
    
    // Nouvel objet dateheure pour dans 7 jours et 30 secondes dans le futur.
    // La syntaxe lue dans RTClib.h montre que l'exemple est faux:
    // TimeSpan (int16_t days, int8_t hours, int8_t minutes, int8_t seconds);
    // C'est cette instruction qui change:
    DateTime future (now + TimeSpan(7,0,0,30) );
    
    Serial.print(" Dans 7 jours et 30 secondes, nous serons le : ");
    Serial.print(future.year(), DEC);
    Serial.print('/');
    Serial.print(future.month(), DEC);
    Serial.print('/');
    Serial.print(future.day(), DEC);
    Serial.print(" a ");
    Serial.print(future.hour(), DEC);
    Serial.print(':');
    Serial.print(future.minute(), DEC);
    Serial.print(':');
    Serial.print(future.second(), DEC);
    Serial.println();
    
    Serial.println();
    delay(3000);
}
